package com.ruoyi.ngtools.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.ngtools.domain.NgComponents;
import com.ruoyi.ngtools.service.INgComponentsService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 天然气组分Controller
 * 
 * @author ruoyi
 * @date 2025-02-09
 */
@RestController
@RequestMapping("/ngtools/components")
public class NgComponentsController extends BaseController
{
    @Autowired
    private INgComponentsService ngComponentsService;

    /**
     * 查询天然气组分列表
     */
    @PreAuthorize("@ss.hasPermi('ngtools:components:list')")
    @GetMapping("/list")
    public TableDataInfo list(NgComponents ngComponents)
    {
        startPage();
        List<NgComponents> list = ngComponentsService.selectNgComponentsList(ngComponents);
        return getDataTable(list);
    }

    /**
     * 导出天然气组分列表
     */
    @PreAuthorize("@ss.hasPermi('ngtools:components:export')")
    @Log(title = "天然气组分", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, NgComponents ngComponents)
    {
        List<NgComponents> list = ngComponentsService.selectNgComponentsList(ngComponents);
        ExcelUtil<NgComponents> util = new ExcelUtil<NgComponents>(NgComponents.class);
        util.exportExcel(response, list, "天然气组分数据");
    }

    /**
     * 获取天然气组分详细信息
     */
    @PreAuthorize("@ss.hasPermi('ngtools:components:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(ngComponentsService.selectNgComponentsById(id));
    }

    /**
     * 新增天然气组分
     */
    @PreAuthorize("@ss.hasPermi('ngtools:components:add')")
    @Log(title = "天然气组分", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody NgComponents ngComponents)
    {
        return toAjax(ngComponentsService.insertNgComponents(ngComponents));
    }

    /**
     * 修改天然气组分
     */
    @PreAuthorize("@ss.hasPermi('ngtools:components:edit')")
    @Log(title = "天然气组分", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody NgComponents ngComponents)
    {
        return toAjax(ngComponentsService.updateNgComponents(ngComponents));
    }

    /**
     * 删除天然气组分
     */
    @PreAuthorize("@ss.hasPermi('ngtools:components:remove')")
    @Log(title = "天然气组分", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        return toAjax(ngComponentsService.deleteNgComponentsByIds(ids));
    }
}
